"use strict";
Object.defineProperty(exports, "__esModule", {
  value: true
});
function _export(target, all) {
  for (var name in all)
    Object.defineProperty(target, name, {
      enumerable: true,
      get: all[name]
    });
}
_export(exports, {
  execaWithStreamLog: () => execaWithStreamLog,
  runInstallWithNvm: () => runInstallWithNvm,
  npmInstall: () => npmInstall,
  yarnInstall: () => yarnInstall,
  pnpmInstall: () => pnpmInstall
});
const _utils = require("@modern-js/utils");
const _env = require("./env");
function execaWithStreamLog(command, args, options) {
  const promise = (0, _utils.execa)(command, args, {
    ...options,
    stdin: "inherit",
    stdout: "inherit",
    stderr: "inherit"
  });
  return promise;
}
async function runInstallWithNvm(command, options) {
  await (0, _utils.execa)(`~/.nvm/nvm-exec ${command}`, {
    ...options,
    shell: true,
    stdin: "inherit",
    stdout: "inherit",
    stderr: "inherit"
  });
}
async function npmInstall({ cwd, registryUrl, ignoreScripts, useNvm }) {
  const canUse = await (0, _env.canUseNpm)();
  if (canUse) {
    const params = [
      "install"
    ];
    if (registryUrl) {
      params.push(`--registry=${registryUrl}`);
    }
    if (ignoreScripts) {
      params.push("--ignore-scripts");
    }
    if (useNvm) {
      return runInstallWithNvm(`npm ${params.join(" ")}`, {
        cwd,
        env: process.env
      });
    }
    return execaWithStreamLog("npm", params, {
      cwd,
      env: process.env
    });
  }
  throw new Error("please install npm first");
}
async function yarnInstall({ cwd, registryUrl, ignoreScripts, useNvm }) {
  const canUse = await (0, _env.canUseYarn)();
  if (canUse) {
    const params = [
      "install"
    ];
    if (registryUrl) {
      params.push(`--registry=${registryUrl}`);
    }
    if (ignoreScripts) {
      params.push("--ignore-scripts");
    }
    if (useNvm) {
      return runInstallWithNvm(`yarn ${params.join(" ")}`, {
        cwd,
        env: process.env
      });
    }
    return execaWithStreamLog("yarn", params, {
      cwd,
      env: process.env
    });
  }
  throw new Error("please install yarn first");
}
async function pnpmInstall({ cwd, registryUrl, ignoreScripts, useNvm }) {
  const canUse = await (0, _env.canUsePnpm)();
  if (canUse) {
    const params = [
      "install"
    ];
    if (registryUrl) {
      params.push(`--registry=${registryUrl}`);
    }
    if (ignoreScripts) {
      params.push("--ignore-scripts");
    }
    if (useNvm) {
      return runInstallWithNvm(`yarn ${params.join(" ")}`, {
        cwd,
        env: process.env
      });
    }
    return execaWithStreamLog("pnpm", params, {
      cwd,
      env: process.env
    });
  }
  throw new Error("please install pnpm first");
}
